/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Fshij"

, "Reply"
: "Përgjigju"

, "Reply To All"
: "Përgjigju të gjithëve"

, "Forward"
: "Përpara"

, "Print Message"
: "Mesazhi Printimit"

, "Print Preview"
: "Premiera Printimit"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Pushim"
 ,"Pushime"

]
, "Account, Accounts"
: [
  "Llogari"
 ,"Llogari"

]
, "Account Name"
: "Emri Llogarisë"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "E-Posta Përdoruesit"

, "User Name (From)"
: "Emër Përdoruesi (Nga)"

, "Organization"
: "Organizata"

, "Signature position"
: "Pozicioni i Nënshkrimit"

, "Above the quote"
: "Mbi kuotën"

, "Below the quote"
: "Nën kuotën"

, "IMAP"
: "IMAP"

, "Host"
: "Pritës(Host)"

, "Port (Default: 143 / SSL: 993)"
: "Porta (e paracaktuar: 143 / SSL:993)"

, "Secure Connection"
: "Lidhje e Sigurtë"

, "None"
: "Anjë"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Emër përdoruesi"

, "Password"
: "Fjalëkalim"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Porta (e paracaktuara:25)"

, "Authentication"
: "Autentifikim"

, "Login"
: "Hyrje"

, "Plain"
: "I thjeshtë"

, "Username (optional)"
: "Emër përdoruesi (opsional)"

, "Password (optional)"
: "Fjalëkalim (opsional)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Sieve"

, "Port (Default: 2000)"
: "Portë (e paracaktuar: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Konfigurime të tjera"

, "Sent Folder Name"
: "Emri i Dosjes së Dërgimeve"

, "Trash Folder Name"
: "Emri i Dosjes së Plehrave"

, "Drafts Folder Name"
: "Emri i Dosjes së Drafteve"

, "Templates Folder Name"
: "Emri i Dosjes së Shablloneve"

, "Display Format"
: "Formati i Shfaqjes"

, "HTML"
: "HTML"

, "Plain Text"
: "Tekst i thjeshtë"

, "Depending on content type (experimental)"
: "Varur nga tipi i përmbajtjes (eksperimentale)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Krijo"

, "Toggle highlighting"
: "Nyjëzo(toggle)Theksimet"

, "Mark read/unread"
: "Shëno lexuar/i palexuar"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Shto Llogari"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Bashkangjitje"

, "Flags"
: "Flamuj"

, "Subject"
: "Subjekti"

, "From (Email)"
: "Nga (E-Postë)"

, "From (Name)"
: "Nga (Emër)"

, "Sender"
: "Dërgues"

, "To"
: "Drejt"

, "Sent"
: "Dërgo"

, "Received"
: "Marrë"

, "Folder, Folders"
: [
  "Dosje"
 ,"Dosje"

]
, "Size"
: "Madhësi"

, "Answered"
: "Përgjigjur"

, "Forwarded"
: "Ridrejtuar"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "Dërgo konfirmimin e leximit"

, "Do you want to send a reading confirmation message?"
: "Doni të dërgoni një mesazh konfimimi të leximit?"

, "Empty Folder"
: "Boshatis Dosjen"

, "Add Folder"
: "Shto Dosje"

, "New {0}"
: "E re {0}"

, "Please enter the name of the new {0}:"
: "Ju lutem vendosni emrin e {0} së re"

, "No {0} added"
: "Asnjë {0} e shtuar "

, "You have to supply a {0} name!"
: "Ju duhet te jepni një emër {0}!"

, "Please wait"
: "Ju lutem prisni"

, "Creating {0}..."
: "Duke krijuar {0}... "

, "Edit Account"
: "Modifiko Llogarinë"

, "Edit Vacation Message"
: "Modifiko Mesazhin e Pushimeve"

, "Edit Filter Rules"
: "Modifiko Rregullat Filtruese"

, "Notifications"
: ""

, "Mark Folder as read"
: "Shënoni Dosjen si të lexuar"

, "Update Folder List"
: "Përditëso Listen e Dosjes"

, "Message not available."
: "Mesazhi i pa disponueshëm"

, "Cancel"
: "Anullo"

, "Ok"
: "Ok"

, "Folders of account {0}"
: "Dosjet e llogarisë {0}"

, "Folders of all accounts"
: "Dosje të tëgjithë llogarive"

, "Compose email"
: "Krijo E-Postë"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "Nga"

, "Add"
: "Shto"

, "Add contact to addressbook"
: "Shto kontakt në bllokun e adresave"

, "Date"
: "Datë"

, "Show or hide header information"
: "Trego ose fshih informacionin e Kokës(header)"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(mesazh i ri)"

, "Select recipients for \"{0}\""
: "Zgjidhni marrësin për \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Flitri i marrësit"

, "All recipients"
: "Të gjithë marrësit"

, "\"{0}\" recipients"
: "\"{0}\" marrës"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Mesazh Pushimesh për {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Lëviz lartë"

, "Move down"
: "Lëviz poshtë"

, "Enable"
: "Mundëso"

, "Disable"
: "Ç'mundëso"

, "ID"
: "ID"

, "Conditions"
: "Kushtet"

, "Action"
: "Veprim"

, "Keep a copy"
: ""

, "is greater than"
: "është më e madhe se"

, "is less than"
: "është më e vogël se"

, "Header \"{0}\" contains \"{1}\""
: "Koka (header) \"{0}\" përmban \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Koka(header) \"{0}\" përputhet me \"{1}\""

, "Sieve Filter Rules"
: "Rregullat fitruese të Sieve"

, "Sieve Filter Rules for {0}"
: "Rregullat filtruese të sieve për {0}"

, "From (Email and Name)"
: "Nga (E-Postë dhe Emër)"

, "To (Email)"
: "Drejt (E-Postë)"

, "To (Email CC)"
: ""

, "Header contains"
: "Koka (header) përmban"

, "Header name"
: "Emri i kokës (header)"

, "Header value"
: "Vlera e Kokës(header)"

, "Header regex"
: "Modeli i Kokës (header regex)"

, "Edit Filter Rule"
: "Modifiko Rregullin e Filtruesit"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Kryej këtë veprim:"

, "Move mail to folder"
: "Lëviz postën në dosje"

, "Redirect mail to address"
: "Ridrejto postën tek adresa"

, "Reject mail with this text"
: "Refuzo postën me këtë tekst"

, "Discard mail"
: "Skarco postën"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Mbaj postën"

, "General"
: "I Përgjithshëm"

, "Advanced"
: "I Përparuar"

, "Only send all X days to the same sender"
: "Dërgoja çdo X ditë të njëjtit dërgues"

, "Incoming mails will be answered with this text:"
: "Posta Hyrese do të përgjigjet me këte tekst:"

, "Status"
: "Statusi"

, "I am available (vacation message disabled)"
: "Unë jam i disponueshëm (mesazhi i pushimeve i ç'aktivizuar)"

, "I am not available (vacation message enabled)"
: "Unë nuk jam i disponueshëm (mesazhi pushimeve i aktivizuar)"

, "Start Date"
: "Data Fillimit"

, "Set vacation start date ..."
: "Vendosni datën e fillimit të pushimeve..."

, "End Date"
: "Data Mbarimit"

, "Set vacation end date ..."
: "Vendosni datën e mbarimit të pushimeve:x.."

, "Representative #1"
: "Përfaqësuesi #1"

, "Choose first Representative ..."
: "Zgjidhni Përfaqësuesin e parë..."

, "Representative #2"
: "Përfaqësuesi #2"

, "Choose second Representative ..."
: "Zgjidhni Përfaqësuesin e dytë..."

, "Message Template"
: "Mesazh Shabllon"

, "Choose Template ..."
: "Zgjidh Shabllonin"

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Mesazh"
 ,"Mesazhe"

]
, "Subject/From"
: "Subjekt/Nga"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "Posta Hyrëse"

, "Drafts"
: "Drafte"

, "Templates"
: "Shabllone"

, "Junk"
: "Hedhurina"

, "Trash"
: "Plehëra"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "lista e të dhënave"
 ,"listat e të dhënave"

]
, "Rule, Rules"
: [
  "Rregull"
 ,"Rregulla"

]
, "Flag, Flags"
: [
  "Flamur"
 ,"Flamuj"

]
, "Flag list, Flag lists"
: [
  "Lista e Flamujve"
 ,"Listat e Flamujve"

]
, "Total Messages:"
: "Mesazhe Gjithsej:"

, "Unread Messages:"
: "Mesazhe të pa lexuara"

, "Name on Server:"
: "Emri në Server"

, "Last update:"
: "Përditësimi i fundit"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} mesazh i palexuar"
 ,"{0} mesazhe të palexuara"

]
, "New Mail"
: "Postë e Re"

, "Email"
: "E-Postë"

, "Active Vacation Message"
: "Mesazh Aktiv Pushimesh "

, "Email account \"{0}\" has an active vacation message."
: "Llogaria e E-Postës  \"{0}\" ka një mesazh aktiv pushimesh"

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Posta të reja"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Ju keni {0} postë të re në dosjen {1} ({2})."

, "IMAP Credentials for {0}"
: "kredencialet IMAP për {0}"

, "Credentials"
: "Kredencialet"

, "IMAP Error"
: "Gabim IMAP"

, "No connection to IMAP server."
: "Nuk ka lidhje tek serveri IMAP"

, "IMAP Credentials Error"
: "Gabim kredencialesh IMAP"

, "Your email credentials are wrong. Please contact your administrator"
: "Kredencialet tuaja të E-Postës janë gabim. Ju lutem kontaktoni administratorin tuaj"

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Një nga dosjet tuaja është fshirë ose riemëruar nga një klient tjetër. Ju lutem përditësonilistën e dosjeve për këtë llogari"

, "SMTP Error"
: "Gabim SMTP"

, "No connection to SMTP server."
: "Nuk ka lidhje tek serveri SMTP"

, "Sieve Error"
: "Gabim Sieve"

, "No connection to Sieve server."
: "Nuk ka lidhje tek servieri Sieve"

, "Save Sieve Script Error"
: "Ruaj gabimin e dorëshkrimit të Sieve "

, "Could not save script on Sieve server."
: "Nuk mund të ruhej dorëshkrimi në serverin e Sieve"

, "Add as \"To\""
: "Shtoje si \"To\""

, "Add as \"Cc\""
: "Shtoje si \"Cc\""

, "Add as \"Bcc\""
: "Shtoje si \"Bcc\""

, "Remove from recipients"
: "Hiqe nga marrësit"

, "Loading Mail Addresses"
: "Duke ngarkuar adresat e postës"

, "Click here to set To/CC/BCC."
: "Kliko këtu për të vendosur Drejt/CC/BCC."

, "To:"
: "Drejt"

, "Cc:"
: "Cc"

, "Bcc:"
: "Bcc"

, "Remove"
: "Hiq"

, "Send"
: "Dërgo"

, "Search Recipients"
: "Kërko Marrës"

, "Save As Draft"
: "Ruaj si Draft"

, "Save As Template"
: "Ruaj si Shabllon"

, "Reading Confirmation"
: "Konfirmim i Leximit"

, "Activate this toggle button to receive a reading confirmation."
: "Aktivizo këtë buton nyjezimesh(toggle) për të pritur nje konfirmim leximi"

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Kliko për te kërkuar dhe shtuar marrës nga Blloku i Adresave"

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Ridrejto:"

, "{0} Message"
: "Mesazhi {0}"

, "Failed"
: "Dështoi"

, "{0} account setting empty."
: "Duke vendosur bosh llogarinë {0}."

, "Files are still uploading."
: "Skedarët janë akoma duke u ngarkuar"

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "Në {0}, {1} shkruajti"

, "Original message"
: "Mesazhi Origjinal"

, "Compose email:"
: "Krijo E-Postë"

, "Convert to formated text"
: ""

, "Body"
: "Trupi"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Subjekt bosh"

, "Do you really want to send a message with an empty subject?"
: "Doni vërtet të dërgoni një mesazh pa subjekt?"

, "No recipients set."
: "Nuk janë vendosur marrës"

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Të gjitha postat hyrëse"

, "Default Email Account"
: "Llogaria E-Postë e paracaktuar"

, "The default email account to use when sending mails."
: "Llogaria E-poste e paracaktuar për tu përdorur kur dërgohet postë"

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Intervali i Përditësimit të E-Postës"

, "How often should Felamimail check for new Emails (in minutes)."
: "Sa shpesh duhet të kërkoje Felamimail për E-postë të re (në minuta)"

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Përdore për SHËNIME"

, "Save Note default Value."
: "Vlera e paracaktuar e shënimit të ruajtjes"

, "Confirm Delete"
: "Konfirmo Fshirjen"

, "Show confirmation dialog when deleting mails."
: "Trego dialogun e konfirmimit kur fshij postë"

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Mesazh Pushimesh i Personalizuar"

, "User is allowed to set custom vacation message for system account"
: "Përdoruesi është i autorizuar të vendosë mesazh pushimesh të personalizuar për llogainë e sistemit"

, "Cache email body"
: "Fshih (chache) trupin e E-Postes"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Duhet që trupi i E-Postës të fshihet(cache) (rekomandohet për lidhjet e ngadalta të serverave IMAP )"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "Konfirmim Leximi:"

, "Your message:"
: "Mesazhi Juaj:"

, "Received on"
: "Marrë në"

, "Was read by:"
: "U lexua nga:"

, "on"
: "në"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Përgjigje 'Jashtë Zyre' nga %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: "Gabim: %s"

, "Could not send message"
: "Nuk mund të dërgohej mesazhi"

, "My Mail Download Links"
: ""

, "Seen"
: "Parë"

, "Deleted"
: "Fshirë"

, "Draft"
: "Draft"

, "Flagged"
: "Shënuar"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Të gjithë Postat Hyrëse për llogaritë e mia E-Postë"

, "All unread mail"
: "Të gjithë postat e palexuara"

, "All unread mail of my email accounts"
: "Të gjithë postat e palexuara të llogarive të mia E-Postë"

, "All highlighted mail"
: "Të gjithë postat e Theksuara"

, "All highlighted mail of my email accounts"
: "Të gjithë postat e theksuara të llogarive të mia E-Postë"

, "All drafts"
: "Gjithë draftet"

, "All mails with the draft flag"
: "Gjithë postat me shënimin Draft"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "menaxho llogaritë e E-Postës"

, "Edit and delete email accounts"
: "Modifiko dhe fshij llogaritë e E-Postës"

, "Add email accounts"
: "Shto llogari E-Poste"

, "Create new email accounts"
: "Krijo llogari të re E-Poste"

, "Vacation"
: "Pushim"

, "Account"
: "Llogari"

, "Folder"
: "Dosje"

, "Message"
: "Mesazh"

, "record list"
: "lista e të dhënave"

, "Rule"
: "Rregull"

, "Flag"
: "Flamur"

, "Flag list"
: "Lista e Flamujve"

, "{0} unread message"
: "{0} mesazh i palexuar"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
